## This code was evaluated for replicability by an independent team of experts (see https://replicability.graphics/ ).
The remainder of this file contains the evaluation report, along with suggestions to successfully compile and run the code.

## Information

- Paper topic: Geometry
- Software type: Code
- Able to run a replicability test: True
- Replicability score: 5
- Paper listed in the Graphics Replicability Stamp Initiative
- Software language: C++
- License: MPL 2.0
- Build mechanism: cmake
- Dependencies: libigl,gmp,tbb,geogram
- Documentation score {0,1,2}: 3
- Reviewer: David Coeurjolly <david.coeurjolly@liris.cnrs.fr>
- Time spent for the test (build->first run, timeout at 100min): 10min

## Source code information

- Code URL: https://github.com/wildmeshing/fTetWild
- Git commit hash: 4c66f57380342e6868f912890c974cc093d505f5
- Software Heritage link:

## Comments

    The build instructions are straightforward to follow (all dependencies are smoothly built at the cmake step). The authors also provide all scripts to replicate all figures of the paper.